@@ -7,5 +7,5 @@ from ..utils import updates
 register = template.Library()
 
 @register.simple_tag
-def updates_url(channel_id):
-    return updates.updates_url(channel_id)
+def channel_url(channel_id):
+    return updates.subscriber_url(channel_id)
